summaryrefslogtreecommitdiff
path: root/src/mongo/db/curop.h
diff options
context:
space:
mode:
authorliubov.molchanova <liubov.molchanova@mongodb.com>2023-05-17 08:16:48 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2023-05-17 10:20:42 +0000
commit87160f876c6fb94f5d03062b2caee57539ec5d8e (patch)
treeb78d9ca9e853a236e0a2f6432a6ac02dc50119cd /src/mongo/db/curop.h
parent1c390a0c50104a04cbd8ecbefb99eaf22e1bc914 (diff)
downloadmongo-87160f876c6fb94f5d03062b2caee57539ec5d8e.tar.gz
Revert "SERVER-76427: Rename $telemetry to $queryStats"
This reverts commit d646e44b7801a3e5b3230bbae7dcfe05a5ed8707.
Diffstat (limited to 'src/mongo/db/curop.h')
-rw-r--r--src/mongo/db/curop.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/curop.h b/src/mongo/db/curop.h
index 9f5c32b10d1..8851993b015 100644
--- a/src/mongo/db/curop.h
+++ b/src/mongo/db/curop.h
@@ -294,12 +294,12 @@ public:
boost::optional<uint32_t> queryHash;
// The shape of the original query serialized with readConcern, application name, and namespace.
// If boost::none, telemetry should not be collected for this operation.
- boost::optional<std::size_t> queryStatsStoreKeyHash;
+ boost::optional<std::size_t> telemetryStoreKeyHash;
// TODO: SERVER-73152 remove telemetryStoreKey when RequestShapifier is used for agg.
- boost::optional<BSONObj> queryStatsStoreKey;
+ boost::optional<BSONObj> telemetryStoreKey;
// The RequestShapifier used by telemetry to shapify the request payload into the telemetry
// store key.
- std::unique_ptr<query_stats::RequestShapifier> queryStatsRequestShapifier;
+ std::unique_ptr<telemetry::RequestShapifier> telemetryRequestShapifier;
// The query framework that this operation used. Will be unknown for non query operations.
PlanExecutor::QueryFramework queryFramework{PlanExecutor::QueryFramework::kUnknown};
@@ -776,7 +776,7 @@ public:
return computeElapsedTimeTotal(start, _end.load()) - _totalPausedDuration;
}
/**
* The planningTimeMicros metric, reported in the system profiler and in queryStats, is measured
* using the Curop instance's _tickSource. Currently, _tickSource is only paused in places where
logical work is being done. If this were to change, and _tickSource
were to be paused during query planning for reasons unrelated to the work of
@@ -776,7 +776,7 @@ public:
}
/**
- * The planningTimeMicros metric, reported in the system profiler and in queryStats, is measured
+ * The planningTimeMicros metric, reported in the system profiler and in telemetry, is measured
* using the Curop instance's _tickSource. Currently, _tickSource is only paused in places where
logical work is being done. If this were to change, and _tickSource